======
okland
======

    Prometheus metrics from static code analyses toolings.


okland is a wrapper around your probably favorite static code analytics toolings. it creates metrics from those. 

**Why** metrics? Because it might be useful to have a interactive dashboard that shows findings of code analysis that occured during build time.

See project information at `Github la3mmchen/okland <https://github.com/la3mmchen/okland/>`_